This project is a temporary project I made for development for study. It is full of strange code with tens of thousands of glitches and bugs (I chose the name "Longinus" because it's just cool)
If you are going to use this project I do not recommend
And if anyone can help to complete this project, please contact me by email :>